@@ -19,8 +19,25 @@ import re
 import click
 import networkx as nx
 
+from outdated import check_outdated # type: ignore
+
 from tgwrap.lib import TgWrap, Printer
 
+from . import __version__
+
+def check_latest_version():
+    # check for newer versions
+    try:
+        is_outdated, latest_version = check_outdated('tgwrap', __version__)
+        if is_outdated:
+            click.echo(
+                f'Your local version ({__version__}) is out of date! Latest is {latest_version}!'
+            )
+    except ValueError:
+        # this happens when your local version is ahead of the pypi version,
+        # which happens only in development
+        pass
+
 CLICK_CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
 class DefaultGroup(click.Group):
@@ -77,7 +94,7 @@ def main():
     ),
 )
 @click.argument('command', type=click.Choice(
-    ['init', 'validate', 'plan', 'apply', 'destroy', 'info', 'output', 'state', 'show']
+    ['init', 'validate', 'validate-inputs', 'plan', 'apply', 'destroy', 'info', 'output', 'state', 'show']
     ))
 @click.option('--verbose', '-v', is_flag=True, default=False,
     help='Verbose printing',
@@ -103,10 +120,17 @@ def main():
     help='Do not ask for confirmation before applying planned changes (where applicable)',
     show_default=True
     )
+@click.option(
+    '--working-dir', '-w', default=None,
+    help='Working directory, when omitted the current directory is used',
+    )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
-def run(command, verbose, debug, dry_run, no_lock, update_source, auto_approve, terragrunt_args):
+@click.version_option(version=__version__)
+def run(command, verbose, debug, dry_run, no_lock, update_source, auto_approve, working_dir, terragrunt_args):
     """ [default] Executes a terragrunt command on a single project """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.run(
         command=command,
@@ -115,6 +139,7 @@ def run(command, verbose, debug, dry_run, no_lock, update_source, auto_approve,
         no_lock=no_lock,
         update_source=update_source,
         auto_approve=auto_approve,
+        working_dir=working_dir,
         terragrunt_args=terragrunt_args,
     )
 
@@ -155,10 +180,18 @@ def run(command, verbose, debug, dry_run, no_lock, update_source, auto_approve,
     help='Run the command step by step and stop when an error occurs (where applicable)',
     show_default=True
     )
+@click.option(
+    '--working-dir', '-w', default=None,
+    help='Working directory, when omitted the current directory is used',
+    )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
-def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_external_dependencies, step_by_step, terragrunt_args):
+@click.version_option(version=__version__)
+def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_external_dependencies,
+    step_by_step, working_dir, terragrunt_args):
     """ Executes a terragrunt command across multiple projects """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.run_all(
         command=command,
@@ -168,6 +201,7 @@ def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_ex
         update_source=update_source,
         exclude_external_dependencies=exclude_external_dependencies,
         step_by_step=step_by_step,
+        working_dir=working_dir,
         terragrunt_args=terragrunt_args,
     )
 
@@ -189,13 +223,21 @@ def run_all(command, verbose, debug, dry_run, no_lock, update_source, exclude_ex
     help='Whether or not external dependencies must be ignored',
     show_default=True
     )
+@click.option(
+    '--working-dir', '-w', default=None,
+    help='Working directory, when omitted the current directory is used',
+    )
 @click.argument('terragrunt-args', nargs=-1, type=click.UNPROCESSED)
-def analyze(verbose, dry_run, exclude_external_dependencies, terragrunt_args):
+@click.version_option(version=__version__)
+def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terragrunt_args):
     """ Analyzes the plan files """
 
+    check_latest_version()
+
     tgwrap = TgWrap(verbose=verbose)
     tgwrap.analyze(
         dry_run=dry_run,
         exclude_external_dependencies=exclude_external_dependencies,
+        working_dir=working_dir,
         terragrunt_args=terragrunt_args,
     )
